# ptb
This is the MMG Repository containing useful tools and development of useful tools for analysing, processing and modelling in python (and matlab)

Contributors: Ted Yeung, Isabella Murrell, Homayoon Zarshenas, Thorben Pauli.

## Requirements
Python 3.10 or above
Packages: 'pandas', 'scipy', 'numpy', 'scikit-learn', 'Pillow', 'vtk', 'PyQt6', 'tsfresh'

## Supported Data formats
### Mocap
c3d, trc, mot (Opensim), sto(Opensim), csv

### Meshes
OBJ, STL, Ply, Vtk

Setup
For using the PTB: * It can be set up using the wheel in the dist folder, which will install ptb into your Python environment.
